@@ -4,16 +4,19 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '1.748';
+our $VERSION = '1.749';
 
 use Exporter qw( import );
 
 our @EXPORT_OK = qw(
     NEXT_get_key
-    CONTROL_SPACE LINE_FEED CARRIAGE_RETURN CONTROL_A CONTROL_B CONTROL_C CONTROL_D CONTROL_E CONTROL_F CONTROL_H
-    CONTROL_I CONTROL_K CONTROL_N CONTROL_P CONTROL_Q CONTROL_R CONTROL_S CONTROL_U CONTROL_X
+    CONTROL_SPACE LINE_FEED CARRIAGE_RETURN
+    CONTROL_A CONTROL_B CONTROL_C CONTROL_D CONTROL_E CONTROL_F CONTROL_H CONTROL_I
+    CONTROL_K CONTROL_N CONTROL_P CONTROL_Q CONTROL_R CONTROL_S CONTROL_U CONTROL_X
     KEY_BTAB KEY_TAB KEY_ESC KEY_SPACE KEY_h KEY_j KEY_k KEY_l KEY_q KEY_Tilde KEY_BSPACE
-    VK_PAGE_UP VK_PAGE_DOWN VK_END VK_HOME VK_LEFT VK_UP VK_RIGHT VK_DOWN VK_INSERT VK_DELETE VK_F1 VK_F2 VK_F3 VK_F4
+    VK_LEFT VK_RIGHT VK_UP VK_DOWN
+    VK_INSERT VK_DELETE VK_HOME VK_END VK_PAGE_UP VK_PAGE_DOWN
+    VK_F1 VK_F2 VK_F3 VK_F4
     ROW COL
     WIDTH_CURSOR TERM_READKEY
 );
